[2021-09-17]
hey, this is a group of tools that has been valuable to me at least at some point over the past 15 years.
some have not been touched since.

some have been used relentlessly for a decade or more.

there is a lot of ugly code here...  if you like it enough to make it better, pull-requests are always welcome :)

throw no shade.  i know it's shitty code.  but some of it is incredibly powerful, as of this writing.

hack fun!
@
